@@ -43,7 +43,7 @@ from movieParser import movie_parser, plot_parser, movie_awards_parser, \
                         soundclips_parser, videoclips_parser, news_parser, \
                         photosites_parser, amazonrev_parser, guests_parser, \
                         business_parser, sales_parser, episodes_parser, \
-                        eprating_parser
+                        eprating_parser, movie_faqs_parser, airing_parser
 from searchMovieParser import search_movie_parser
 from personParser import maindetails_parser, bio_parser, \
                         otherworks_parser, person_awards_parser, \
@@ -268,6 +268,10 @@ class IMDbHTTPAccessSystem(IMDbBase):
             cont = self._retrieve(imdbURL_movie % movieID + 'maindetails')
         return movie_parser.parse(cont)
 
+    def get_movie_full_credits(self, movieID):
+        cont = self._retrieve(imdbURL_movie % movieID + 'fullcredits')
+        return movie_parser.parse(cont)
+
     def get_movie_plot(self, movieID):
         cont = self._retrieve(imdbURL_movie % movieID + 'plotsummary')
         return plot_parser.parse(cont)
@@ -413,6 +417,14 @@ class IMDbHTTPAccessSystem(IMDbBase):
                 episode['episode of'].movieID = movieID
         return data_d
 
+    def get_movie_faqs(self, movieID):
+        cont = self._retrieve(imdbURL_movie % movieID + 'faq')
+        return movie_faqs_parser.parse(cont)
+
+    def get_movie_airing(self, movieID):
+        cont = self._retrieve(imdbURL_movie % movieID + 'tvschedule')
+        return airing_parser.parse(cont)
+
     def _search_person(self, name, results):
         # The URL of the query.
         # XXX: To retrieve the complete results list:
