@@ -230,6 +230,8 @@ class HTMLMovieParser(ParserBase):
             # To not override the other section with the same name.
             if self._current_section == 'special effects':
                 self._current_section = 'special effects companies'
+            elif self._current_section == 'other companies':
+                self._current_section = 'miscellaneous companies'
         # Sections like 'cast', 'director', 'writer', etc. all
         # begin with a link to a "/Glossary" page.
         elif link.startswith('/glossary'):
@@ -586,13 +588,19 @@ class HTMLMovieParser(ParserBase):
                 self._in_series_info = 1
         elif self._in_blackcatheader:
             # An hack to support also the tv series' pages.
-            if sldata == 'cast':
+            if sldata in ('series cast summary:', 'series cast',
+                            'cast:', 'cast'):
                 self._is_cast_crew = 1
                 self._current_section = 'cast'
             else:
                 self._cur_blackcatheader += data
         if self.mdparse:
-            if sldata.startswith('cast overview, first billed only'):
+            if sldata[:7] == 'series ':
+                sldata = sldata[7:]
+            if sldata.startswith('cast overview'):
+                self._is_cast_crew = 1
+                self._current_section = 'cast'
+            elif sldata.startswith('cast summary'):
                 self._is_cast_crew = 1
                 self._current_section = 'cast'
             elif sldata.startswith('directed by'):
@@ -2555,7 +2563,7 @@ class HTMLEpisodesParser(ParserBase):
     def _reset(self):
         self._in_html_title = 0
         self._series = None
-        self._html_title = ''
+        self._html_title = u''
         self._episodes = {}
         self._in_h1 = 0
         self._in_episodes_h1 = 0
@@ -2565,12 +2573,14 @@ class HTMLEpisodesParser(ParserBase):
         self._in_td_eps = 0
         self._in_td_title = 1
         self._in_title = 0
-        self._cur_title = ''
+        self._cur_title = u''
         self._curid = ''
+        self._lastid = ''
         self._eps_counter = 1
         self._cur_info = 'title'
         self._info = {}
-        self._info_text = ''
+        self._info_text = u''
+        self._ignore_this_table = 0
 
     def get_data(self):
         if self._episodes: return {'episodes': self._episodes}
@@ -2596,23 +2606,31 @@ class HTMLEpisodesParser(ParserBase):
         self._in_h1 = 0
 
     def start_table(self, attrs):
+        if self._in_td_eps: self._ignore_this_table = 1
         if self._in_episodes_h1:
             self._in_episodes = 1
 
     def end_table(self):
-        self._in_episodes = 0
+        if self._ignore_this_table:
+            self._ignore_this_table = 0
+            return
+
+    def do_hr(self, attrs):
+        self._in_td_eps = 0
 
     def start_a(self, attrs):
-        if not self._in_episodes: return
-        if self._in_td_title:
-            href = self.get_attr_value(attrs, 'href')
-            if href and href.startswith('/title/tt'):
-                curid = self.re_imdbID.findall(href)
-                if curid:
+        if self._ignore_this_table: return
+        href = self.get_attr_value(attrs, 'href')
+        if href and href.startswith('/title/tt'):
+            curid = self.re_imdbID.findall(href)
+            if curid:
+                if self._in_td_title:
                     self._in_title = 1
-                    self._cur_title = ''
+                    self._cur_title = u''
                     self._curid = curid[-1]
                     return
+                else:
+                    self._lastid = curid
         name = self.get_attr_value(attrs, 'name')
         if name and name.lower().startswith('season-'):
             cs = name[7:]
@@ -2622,13 +2640,16 @@ class HTMLEpisodesParser(ParserBase):
             self._eps_counter = 1
 
     def end_a(self):
+        if self._ignore_this_table: return
         if self._in_title: self._in_title = 0
 
     def start_td(self, attrs):
+        if self._ignore_this_table: return
         if self._in_episodes:
             self._in_td_eps = 1
 
     def end_td(self):
+        if self._ignore_this_table: return
         if self._in_td_title:
             self._in_td_eps = 0
             self._in_td_title = 0
@@ -2652,11 +2673,12 @@ class HTMLEpisodesParser(ParserBase):
                 m['episode'] = ce
                 self._episodes[self._cur_season][ce] = m
                 self._eps_counter += 1
-                self._cur_title = ''
+                self._cur_title = u''
                 self._curid = ''
                 self._cur_episode = None
                 for key, value in self._info.items():
                     if key == 'original air date':
+                        value = value[18:].strip()
                         if value[-4:].isdigit() and \
                                     m.get('year', '????') == '????':
                             m['year'] = value[-4:]
@@ -2666,6 +2688,7 @@ class HTMLEpisodesParser(ParserBase):
             self._info = {}
 
     def do_br(self, attrs):
+        if self._ignore_this_table: return
         if self._in_td_title:
             self._info_text = self._info_text.strip()
             if self._info_text and self._cur_info != 'title':
@@ -2677,6 +2700,7 @@ class HTMLEpisodesParser(ParserBase):
                 self._cur_info = 'plot'
 
     def _handle_data(self, data):
+        if self._ignore_this_table: return
         if self._in_h1 and data.strip().lower().startswith('episodes'):
             self._in_episodes_h1 = 1
         elif self._in_td_eps:
@@ -2692,6 +2716,11 @@ class HTMLEpisodesParser(ParserBase):
                     try: ce = int(ce)
                     except: ce = None
                     self._cur_episode = ce
+            elif ldata.find('episode dated') != -1:
+                self._in_td_title = 1
+                self._cur_title = data.strip()
+                self._curid = self._lastid
+                self._cur_episode = self._eps_counter
         elif self._in_html_title:
             self._html_title += data
         if self._in_title:
@@ -2700,6 +2729,213 @@ class HTMLEpisodesParser(ParserBase):
             self._info_text += data
 
 
+class HTMLFaqsParser(ParserBase):
+    """Parser for the "FAQ" page of a given movie.
+    The page should be provided as a string, as taken from
+    the akas.imdb.com server.  The final result will be a
+    dictionary, with a key for every relevant section.
+
+    Example:
+        fparser = HTMLFaqsParser()
+        result = fparser.parse(faqs_html_string)
+    """
+
+    getRefs = 1
+
+    def _reset(self):
+        self._faqs = []
+        self._in_content = 0
+        self._in_question = 0
+        self._in_answer = 0
+        self._question = u''
+        self._answer = u''
+        self._in_spoiler = 0
+        self._in_pre = 0
+
+    def get_data(self):
+        if not self._faqs: return {}
+        return {'faqs': self._faqs}
+
+    def start_pre(self, attrs): self._in_pre = 1
+
+    def end_pre(self): self._in_pre = 0
+
+    def start_ul(self, attrs):
+        self._in_content = 0
+        self._question = u''
+        self._answer = u''
+        self._in_question = 0
+        self._in_answer = 0
+
+    def end_ul(self): pass
+
+    def start_div(self, attrs):
+        cls = self.get_attr_value(attrs, 'class')
+        if cls and cls.strip().lower() == 'swiki_content':
+            self._in_content = 1
+            self._in_question = 1
+            self._in_answer = 0
+
+    def end_div(self):
+        if not self._in_content: return
+        self._question = self._question.strip()
+        self._answer = self._answer.strip()
+        if self._question and self._answer:
+            self._faqs.append(u'%s::%s' % (self._question, self._answer))
+            self._in_content = 0
+            self._in_question = 0
+            self._in_answer = 0
+            self._question = u''
+            self._answer = u''
+
+    def start_h3(self, attrs):
+        if not self._in_content: return
+        self._in_question = 1
+
+    def end_h3(self):
+        if not self._in_content: return
+        self._in_question = 0
+        self._in_answer = 1
+
+    def do_br(self, attrs):
+        if self._in_answer and self._answer:
+            self._answer += '\n'
+
+    def start_span(self, attrs):
+        if not self._in_content: return
+        cls = self.get_attr_value(attrs, 'class')
+        if cls and cls.strip().lower():
+            self._in_spoiler = 1
+        else:
+            return
+        if self._in_answer:
+            self._answer += u'[spoiler]'
+        elif self._in_question:
+            self._question += u'[spoiler]'
+
+    def end_span(self):
+        if not self._in_spoiler: return
+        self._in_spoiler = 0
+        if self._in_answer:
+            self._answer += u'[/spoiler]'
+        elif self._in_question:
+            self._question += u'[/spoiler]'
+
+    def _handle_data(self, data):
+        if not self._in_content: return
+        if self._in_answer:
+            if not self._in_pre: data = data.replace('\n', ' ')
+            self._answer += data
+        elif self._in_question:
+            self._question += data
+
+
+class HTMLAiringParser(ParserBase):
+    """Parser for the "airing" page of a given movie.
+    The page should be provided as a string, as taken from
+    the akas.imdb.com server.  The final result will be a
+    dictionary, with a key for every relevant section.
+
+    Example:
+        aparser = HTMLAiringParser()
+        result = aparser.parse(airing_html_string)
+    """
+
+    getRefs = 0
+
+    def _reset(self):
+        self._air = []
+        self._in_air_info = 0
+        self._in_ch = 0
+        self._cur_info = 'date'
+        self._cur_data = {}
+        self._cur_txt = u''
+        self._in_html_title = 0
+        self._title = u''
+        self._title_kind = ''
+        self._cur_id = ''
+
+    def get_data(self):
+        if not self._air: return {}
+        return {'airing': self._air}
+
+    def start_title(self, attrs): self._in_html_title = 1
+
+    def end_title(self):
+        self._in_html_title = 0
+        self._title = self._title.strip()
+        self._title_kind = analyze_title(self._title, canonical=1)['kind']
+
+    def start_a(self, attrs):
+        href = self.get_attr_value(attrs, 'href')
+        if not href: return
+        ids = self.re_imdbID.findall(href)
+        if ids:
+            self._cur_id = ids[-1]
+
+    def end_a(self): pass
+
+    def start_b(self, attrs):
+        cls = self.get_attr_value(attrs, 'class')
+        if cls and cls.strip().lower() == 'ch':
+            self._in_ch = 1
+
+    def end_b(self): pass
+
+    def start_table(self, attrs): pass
+
+    def end_table(self): self._in_air_info = 0
+
+    def start_td(self, attrs):
+        if not self._in_air_info: return
+        self._cur_txt = u''
+
+    def end_td(self):
+        if not self._in_air_info: return
+        self._cur_txt = self._cur_txt.strip()
+        if self._cur_txt and self._cur_info != 'episode':
+            self._cur_data[self._cur_info] = self._cur_txt
+            self._cur_txt = u''
+        if self._cur_info == 'date':
+            self._cur_info = 'time'
+        elif self._cur_info == 'time':
+            self._cur_info = 'channel'
+        elif self._cur_info == 'channel':
+            self._cur_info = 'episode'
+        elif self._cur_info == 'episode':
+            if self._title_kind == 'episode':
+                self._cur_info = 'date'
+            else:
+                self._cur_info = 'season'
+            if self._cur_txt and self._title:
+                m = Movie(title='%s {%s}' % (self._title, self._cur_txt),
+                            movieID=str(self._cur_id), accessSystem='http')
+                self._cur_data['episode'] = m
+        elif self._cur_info == 'season':
+            self._cur_info = 'episode'
+
+    def start_tr(self, attrs):
+        if not self._in_air_info: return
+        self._cur_txt = u''
+        self._cur_data = {}
+        self._cur_info = 'date'
+
+    def end_tr(self):
+        if not self._in_air_info: return
+        if self._cur_data:
+            if 'episode' in self._cur_data:
+                self._air.append(self._cur_data)
+            self._cur_data = {}
+
+    def _handle_data(self, data):
+        if self._in_ch and data.lower().startswith('next us tv airing'):
+            self._in_air_info = 1
+        if self._in_html_title:
+            self._title += data
+        if not self._in_air_info: return
+        self._cur_txt += data
+
+
 # The used instances.
 movie_parser = HTMLMovieParser()
 plot_parser = HTMLPlotParser()
@@ -2744,4 +2980,6 @@ guests_parser = HTMLGuestsParser()
 sales_parser = HTMLSalesParser()
 episodes_parser = HTMLEpisodesParser()
 eprating_parser = HTMLEpisodesRatings()
+movie_faqs_parser = HTMLFaqsParser()
+airing_parser = HTMLAiringParser()
 
