@@ -96,6 +96,10 @@ sgmlentity.update(dict([('#34', u'"'), ('#38', u'&'),
 re_sgmlref = re.compile('&(%s);' % '|'.join(map(re.escape, sgmlentity)))
 re_sgmlrefsub = re_sgmlref.sub
 
+# Matches XML-only single tags, like <br/> ; they are unvalid in HTML,
+# but sometimes they can be found.
+re_xmltags = re.compile('<([a-zA-Z]+)/>')
+
 
 def _replXMLRef(match):
     """Replace the matched XML/HTML entities and references;
@@ -170,8 +174,8 @@ class ParserBase(SGMLParser):
         self._titlesRefs = {}
         self._titleRefCID = ''
         self._nameRefCID = ''
-        self._titleCN = ''
-        self._nameCN = ''
+        self._titleCN = u''
+        self._nameCN = u''
         self._inTTRef = 0
         self._inLinkTTRef = 0
         self._inNMRef = 0
@@ -223,7 +227,7 @@ class ParserBase(SGMLParser):
                     except IMDbParserError:
                         pass
                 self._titleRefCID = ''
-                self._titleCN = ''
+                self._titleCN = u''
                 self._inTTRef = 0
                 self._inLinkTTRef = 0
         elif self._nameRefCID and self._nameCN:
@@ -239,7 +243,7 @@ class ParserBase(SGMLParser):
                 except IMDbParserError:
                     pass
             self._nameRefCID = ''
-            self._nameCN = ''
+            self._nameCN = u''
             self._inNMRef = 0
 
     def _refs_anchor_bgn(self, attrs):
@@ -304,6 +308,8 @@ class ParserBase(SGMLParser):
         if not isinstance(html_string, UnicodeType):
             html_string = unicode(html_string, 'latin_1', 'replace')
         html_string = subXMLRefs(html_string)
+        # Fix invalid HTML single tags like <br/>
+        html_string = re_xmltags.sub('<\\1 />', html_string)
         self.feed(html_string)
         if self.getRefs and self._inTTRef: self._add_ref('tt')
         data = self.get_data()
